@@ -1,5 +1,6 @@
 # -*- coding:utf-8 -*-
 from ._util import *
+import subprocess
 
 def copyfile(src_file,des_file,auto_create=True):
     """
@@ -17,9 +18,11 @@ def copyfile(src_file,des_file,auto_create=True):
         if iswin():
             src_file = src_file.replace('/', '\\')
             des_file = des_file.replace('/', '\\')
-            os.popen('copy "%s" "%s"' % (src_file, des_file))
+            # os.popen('copy "%s" "%s"' % (src_file, des_file))
+            subprocess.Popen(['copy',src_file,des_file],shell=True)
         else:
-            os.popen('cp "%s" "%s"' % (src_file, des_file))
+            # os.popen('cp "%s" "%s"' % (src_file, des_file))
+            subprocess.Popen(['cp',src_file,des_file],shell=True)
     else:
         print('复制对象非文件类型')
 
@@ -39,9 +42,11 @@ def copydir(src_dir,des_dir,auto_create=True):
         if iswin():
             src_dir = src_dir.replace('/', '\\')
             des_dir = des_dir.replace('/', '\\')
-            os.popen('xcopy "%s" "%s" /s /e /v /y /i' % (src_dir, des_dir))
+            # os.popen('xcopy "%s" "%s" /s /e /v /y /i' % (src_dir, des_dir))
+            subprocess.Popen(['xcopy',src_dir,des_dir,'/s','/e','/v','/y','/i'],shell=True)
         else:
-            os.popen('cp -r "%s" "%s"' % (src_dir, des_dir))
+            # os.popen('cp -r "%s" "%s"' % (src_dir, des_dir))
+            subprocess.Popen(['cp','-r',src_dir,des_dir],shell=True)
     else:
         print('复制对象非目录类型')
 
@@ -64,15 +69,19 @@ def copyall(src,des,auto_create=True):
             if not os.path.exists(_dir):
                 os.makedirs(_dir)
         if iswin():
-            os.popen('copy "%s" "%s"' % (src, des))
+            # os.popen('copy "%s" "%s"' % (src, des))
+            subprocess.Popen(['xcopy',src,des],shell=True)
         else:
-            os.popen('cp "%s" "%s"' % (src, des))
+            # os.popen('cp "%s" "%s"' % (src, des))
+            subprocess.Popen(['cp',src,des],shell=True)
 
     if isdir(src):
         _dir = os.path.dirname(des)
         if not os.path.exists(_dir):
             os.makedirs(_dir)
         if iswin():
-            os.popen('xcopy "%s" "%s" /s /e /v /y /i' % (src, des))
+            # os.popen('xcopy "%s" "%s" /s /e /v /y /i' % (src, des))
+            subprocess.Popen(['xcopy',src,des,'/s','/e','/v','/y','/i'],shell=True)
         else:
-            os.popen('cp -r "%s" "%s"' % (src, des))
\ No newline at end of file
+            # os.popen('cp -r "%s" "%s"' % (src, des))
+            subprocess.Popen(['cp','-r',src,des],shell=True)
\ No newline at end of file
